# license (SPDX): GPL-2.0-only
#
# authors: Kenneth Hoste (Ghent University)

import subprocess
import sys
import tempfile
import typer
from rich import print as rich_print
from typing import Annotated

app = typer.Typer()


def report_error(msg, exit_code: int = 1):
    """
    Report error and exit with specified non-zero exit code
    """
    rich_print(f"[bold red]{msg}", file=sys.stderr)
    if exit_code <= 0:
        raise ValueError(f"Exit code should be positive non-zero integer, got {exit_code}")
    sys.exit(exit_code)


@app.command()
def shell(
    eessi_version: Annotated[str, typer.Option(help="EESSI version")] = '',
):
    """
    Create subshell in which EESSI is available and initialised
    """
    if not eessi_version:
        report_error("EESSI version to use is not specified, which is required!")

    init_file = tempfile.mkstemp()[1]
    with open(init_file, 'w') as fp:
        fp.write(f"set -e; source /cvmfs/software.eessi.io/versions/{eessi_version}/init/bash")

    res = subprocess.run(['/bin/bash', '--init-file', init_file, '-i'])
    if res.returncode != 0:
        report_error("ERROR: Non-zero exit code detected for interactive shell!", exit_code=res.returncode)



# license (SPDX): GPL-2.0-only
#
# authors: Kenneth Hoste (Ghent University)

import typer

app = typer.Typer()


@app.command()
def check():
    """
    Check CernVM-FS setup for accessing EESSI
    """
    raise NotImplementedError



# license (SPDX): GPL-2.0-only
#
# authors: Kenneth Hoste (Ghent University)

import os
import sys
import typer

app = typer.Typer()


@app.command()
def init():
    """
    Initialize shell environment for using EESSI
    """
    eessi_path = os.path.join("/cvmfs", "software.eessi.io", "versions", "2023.06")
    if os.path.exists(eessi_path):
        print("# Commands to prepare your session environment for using EESSI (https://eessi.io/docs)")
        print("# Use eval so commands below are used to set up your environment: eval \"$(eessi init)\"")
        print("source /cvmfs/software.eessi.io/versions/2023.06/init/bash")
    else:
        sys.stderr.write(f"ERROR: {eessi_path} does not exist!\n")
        eessi_docs_access = "https://eessi.io/docs/getting_access/is_eessi_accessible"
        sys.stderr.write(f"See {eessi_docs_access} for information on how to get access to EESSI.\n")
        sys.exit(1)



# license (SPDX): GPL-2.0-only
#
# authors: Kenneth Hoste (Ghent University)

import typer

import eessi
from eessi.cli.check import app as check_app
from eessi.cli.init import app as init_app
from eessi.cli.shell import app as shell_app

app = typer.Typer(
    help="User-friendly command line interface to EESSI - https://eessi.io",
    context_settings={"help_option_names": ["-h", "--help"]},
    no_args_is_help=True,
)

app.add_typer(check_app)
app.add_typer(init_app)
app.add_typer(shell_app)

def version_callback(value: bool):
    if value:
        print(f"eessi version {eessi.__version__}")
        raise typer.Exit()


@app.callback()
def main(
    version: bool = typer.Option(
        None,  # default value
        "-v",  # short option
        "--version",  # long option
        help="Show version of eessi CLI",
        callback=version_callback,
    ),
):
    pass


if __name__ == "__main__":
    app()
